@@ -1,6 +1,5 @@
 from __future__ import annotations
 
-import inspect
 from typing import (
     Any,
     Callable,
@@ -18,23 +17,25 @@ from pydantic import BaseModel, ValidationError
 from typing_extensions import Literal
 
 from ._plugin_manager import PluginManager
-from .manifest.commands import CommandContribution
-from .manifest.contributions import ContributionPoints
-from .manifest.readers import ReaderContribution
-from .manifest.sample_data import SampleDataGenerator
+from .manifest.contributions import (
+    CommandContribution,
+    ContributionPoints,
+    ReaderContribution,
+    SampleDataGenerator,
+    WidgetContribution,
+    WriterContribution,
+)
 from .manifest.schema import PluginManifest
-from .manifest.widgets import WidgetContribution
-from .manifest.writers import WriterContribution
 
 C = TypeVar("C", bound=BaseModel)
 T = TypeVar("T", bound=Callable[..., Any])
 
-COMMAND_PARAMS = inspect.signature(CommandContribution).parameters
+
 # a mapping of contribution type to string name in the ContributionPoints
 # e.g. {ReaderContribution: 'readers'}
 CONTRIB_NAMES = {v.type_: k for k, v in ContributionPoints.__fields__.items()}
 for key in list(CONTRIB_NAMES):
-    if getattr(key, "__origin__", "") is Union:
+    if getattr(key, "__origin__", "") == Union:
         v = CONTRIB_NAMES.pop(key)
         for t in key.__args__:
             CONTRIB_NAMES[t] = v
@@ -67,6 +68,16 @@ class DynamicPlugin:
         self.contribute = ContributionDecorators(self)
         self._pm = plugin_manager
 
+    @property
+    def name(self) -> str:
+        """Name of the plugin"""
+        return self.manifest.name
+
+    @property
+    def display_name(self) -> str:
+        """Display name of the plugin"""
+        return self.manifest.display_name
+
     def cleanup(self) -> None:
         """Remove this plugin from its plugin manager"""
         self.plugin_manager.unregister(self.manifest.name)
@@ -113,6 +124,44 @@ class DynamicPlugin:
     def __exit__(self, *_) -> None:
         self.cleanup()
 
+    def spawn(
+        self,
+        name: Optional[str] = None,
+        plugin_manager: Optional[PluginManager] = None,
+        register: bool = False,
+    ) -> DynamicPlugin:
+        """Create a new DynamicPlugin instance with the same plugin manager.
+
+        Parameters
+        ----------
+        name : Optional[str]
+            If not provided, will increment current name, by default None
+        plugin_manager : Optional[PluginManager]
+            Plugin manager, by default the same as this plugin's plugin manager
+        register : bool
+            Whether to register the new plugin, by default False
+
+        Returns
+        -------
+        DynamicPlugin
+            A new DynamicPlugin instance.
+        """
+        pm = plugin_manager or self.plugin_manager
+        assert isinstance(pm, PluginManager), "plugin_manager must be a PluginManager"
+
+        if name:
+            assert name not in pm._manifests, f"name {name!r} already in plugin manager"
+            _name = name
+        else:
+            i = 1
+            while (_name := f"{self.name}-{i}") in pm._manifests:
+                i += 1
+
+        new = type(self)(_name, plugin_manager=pm)
+        if register:
+            new.register()
+        return new
+
 
 class ContributionDecorators:
     """A set of decorators that facilitate adding contributions to a TemporaryPlugin.
@@ -204,7 +253,11 @@ class ContributionDecorator(Generic[C]):
         """Create a new command contribution for `func`"""
         kwargs.setdefault("title", func.__name__)
         kwargs.setdefault("id", f"{self.plugin.manifest.name}.{func.__name__}")
-        cmd_kwargs = {k: kwargs.pop(k) for k in list(kwargs) if k in COMMAND_PARAMS}
+        cmd_kwargs = {
+            k: kwargs.pop(k)
+            for k in list(kwargs)
+            if k in CommandContribution.__fields__
+        }
         cmd = CommandContribution(**cmd_kwargs)
         self.commands.append(cmd)
         self.plugin.plugin_manager.commands.register(cmd.id, func)
