@@ -28,7 +28,7 @@ from ._command_registry import CommandRegistry
 from .manifest import PluginManifest
 from .manifest._npe1_adapter import NPE1Adapter
 from .manifest.contributions import LayerType, WriterContribution
-from .types import PathLike, PythonName, _ensure_str_or_seq_str
+from .types import PathLike, PythonName
 
 if TYPE_CHECKING:
     from .manifest.contributions import (
@@ -111,21 +111,18 @@ class _ContributionsIndex:
     def get_command(self, command_id: str) -> CommandContribution:
         return self._commands[command_id][0]
 
-    def iter_compatible_readers(
-        self, path: Union[str, Sequence[str]]
-    ) -> Iterator[ReaderContribution]:
-        _ensure_str_or_seq_str(path)
+    def iter_compatible_readers(self, paths: List[str]) -> Iterator[ReaderContribution]:
+        assert isinstance(paths, list)
+        if not paths:
+            return  # pragma: no cover
+
+        if len({Path(i).suffix for i in paths}) > 1:
+            raise ValueError(
+                "All paths in the stack list must have the same extension."
+            )
+        path = paths[0]
         if not path:
             return
-
-        if isinstance(path, list):
-            if len({Path(i).suffix for i in path}) > 1:
-                raise ValueError(
-                    "All paths in the stack list must have the same extension."
-                )
-            path = path[0]
-        path = str(path)
-
         assert isinstance(path, str)
 
         if os.path.isdir(path):
@@ -156,32 +153,23 @@ class _ContributionsIndex:
                 if layer == lt and (min_ <= counts[lt] < max_)
             }
 
-        candidates = {w for _, _, _, w in self._writers}
+        # keep ordered without duplicates
+        candidates = list({w: None for _, _, _, w in self._writers})
         for lt in LayerType:
             if candidates:
-                candidates &= _get_candidates(lt)
+                candidates = [i for i in candidates if i in _get_candidates(lt)]
             else:
                 break
 
-        def _writer_key(writer: WriterContribution) -> Tuple[bool, int, int, List[str]]:
+        def _writer_key(writer: WriterContribution) -> Tuple[bool, int]:
             # 1. writers with no file extensions (like directory writers) go last
             no_ext = len(writer.filename_extensions) == 0
 
             # 2. more "specific" writers first
             nbounds = sum(not c.is_zero() for c in writer.layer_type_constraints())
+            return (no_ext, nbounds)
 
-            # 3. then sort by the number of listed extensions
-            #    (empty set of extensions goes last)
-            ext_len = len(writer.filename_extensions)
-
-            # 4. finally group related extensions together
-            exts = writer.filename_extensions
-            return (no_ext, nbounds, ext_len, exts)
-
-        yield from sorted(
-            candidates,
-            key=_writer_key,
-        )
+        yield from sorted(candidates, key=_writer_key)
 
 
 class PluginManagerEvents(SignalGroup):
@@ -243,7 +231,7 @@ class PluginManager:
 
     @classmethod
     def instance(cls) -> PluginManager:
-        """Singleton instance."""
+        """Return global PluginManager singleton instance."""
         if cls.__instance is None:
             cls.__instance = cls()
         return cls.__instance
@@ -286,6 +274,7 @@ class PluginManager:
                     self.register(result.manifest, warn_disabled=False)
 
     def index_npe1_adapters(self):
+        """Import and index any/all npe1 adapters."""
         with warnings.catch_warnings():
             warnings.showwarning = lambda e, *_: print(str(e).split(" Please add")[0])
             while self._npe1_adapters:
@@ -310,6 +299,7 @@ class PluginManager:
         self.events.plugins_registered.emit({manifest})
 
     def unregister(self, key: PluginName):
+        """Unregister plugin named `key`."""
         if key not in self._manifests:
             raise ValueError(f"No registered plugin named {key!r}")  # pragma: no cover
         self.deactivate(key)
@@ -406,7 +396,7 @@ class PluginManager:
     # Getting manifests
 
     def get_manifest(self, plugin_name: str) -> PluginManifest:
-        """Gen manifest for `plugin_name`"""
+        """Get manifest for `plugin_name`"""
         key = str(plugin_name).split(".")[0]
         try:
             return self._manifests[key]
@@ -445,34 +435,64 @@ class PluginManager:
     # Accessing Contributions
 
     def get_command(self, command_id: str) -> CommandContribution:
+        """Retrieve CommandContribution for `command_id`"""
         return self._contrib.get_command(command_id)
 
     def get_submenu(self, submenu_id: str) -> SubmenuContribution:
+        """Get SubmenuContribution for `submenu_id`."""
         for mf in self.iter_manifests(disabled=False):
             for subm in mf.contributions.submenus or ():
                 if submenu_id == subm.id:
                     return subm
         raise KeyError(f"No plugin provides a submenu with id {submenu_id}")
 
-    def iter_menu(self, menu_key: str) -> Iterator[MenuItem]:
-        for mf in self.iter_manifests(disabled=False):
-            yield from getattr(mf.contributions.menus, menu_key, ())
+    def iter_menu(self, menu_key: str, disabled=False) -> Iterator[MenuItem]:
+        """Iterate over `MenuItems` in menu with id `menu_key`."""
+        for mf in self.iter_manifests(disabled=disabled):
+            yield from mf.contributions.menus.get(menu_key, ())
+
+    def menus(self, disabled=False) -> Dict[str, List[MenuItem]]:
+        """Return all registered menu_key -> List[MenuItems]."""
+        _menus: DefaultDict[str, List[MenuItem]] = DefaultDict(list)
+        for mf in self.iter_manifests(disabled=disabled):
+            for key, menus in mf.contributions.menus.items():
+                _menus[key].extend(menus)
+        return dict(_menus)
 
     def iter_themes(self) -> Iterator[ThemeContribution]:
+        """Iterate over discovered/enuabled `ThemeContributions`."""
         for mf in self.iter_manifests(disabled=False):
             yield from mf.contributions.themes or ()
 
     def iter_compatible_readers(
         self, path: Union[PathLike, Sequence[str]]
     ) -> Iterator[ReaderContribution]:
+        """Iterate over ReaderContributions compatible with `path`.
+
+        Parameters
+        ----------
+        path : Union[PathLike, Sequence[str]]
+            Pathlike or list of pathlikes, with file(s) to read.
+        """
+        if isinstance(path, (str, Path)):
+            path = [path]
+        assert isinstance(path, list)
         return self._contrib.iter_compatible_readers(path)
 
     def iter_compatible_writers(
         self, layer_types: Sequence[str]
     ) -> Iterator[WriterContribution]:
+        """Iterate over compatible WriterContributions given a sequence of layer_types.
+
+        Parameters
+        ----------
+        layer_types : Sequence[str]
+            list of lowercase Layer type names like `['image', 'labels']`
+        """
         return self._contrib.iter_compatible_writers(layer_types)
 
     def iter_widgets(self) -> Iterator[WidgetContribution]:
+        """Iterate over discovered WidgetContributions."""
         for mf in self.iter_manifests(disabled=False):
             yield from mf.contributions.widgets or ()
 
